const uuid = require('uuid')
const collectionHelper = require('./Collection')

const getInvitationData = (invitations, userId, role) => {
  const matchingInvitation = invitations.find(
    inv => inv.role === role && inv.userId === userId,
  )
  let status = 'pending'
  if (matchingInvitation.isAccepted) {
    status = 'accepted'
  } else if (matchingInvitation.hasAnswer) {
    status = 'declined'
  }

  const { timestamp, id } = matchingInvitation
  return { timestamp, status, id }
}

const setupInvitation = async (userId, role, collection) => {
  const invitation = {
    role,
    hasAnswer: false,
    isAccepted: false,
    timestamp: Date.now(),
    id: uuid.v4(),
    userId,
  }
  collection.invitations = collection.invitations || []
  collection.invitations.push(invitation)
  collection = await collection.save()
  return invitation
}

const setupReviewerInvitation = async ({
  baseUrl,
  FragmentModel,
  UserModel,
  collection,
  user,
  mailService,
  invitationId,
  timestamp,
  resend = false,
}) => {
  const {
    title,
    authorName,
    id,
    abstract,
    authrosList,
  } = await collectionHelper.getFragmentAndAuthorData({
    UserModel,
    FragmentModel,
    collection,
  })

  const params = {
    invitedUser: user,
    baseUrl,
    collection: {
      id: collection.id,
      authorName,
      handlingEditor: collection.handlingEditor,
    },
    subject: `${collection.customId}: Review Requested`,
    fragment: {
      id,
      title,
      abstract,
      authrosList,
    },
    invitation: {
      id: invitationId,
      timestamp,
    },
    resend,
  }
  await mailService.setupReviewerInvitationEmail(params)
}

const getInvitation = (invitations = [], userId, role) =>
  invitations.find(
    invitation => invitation.userId === userId && invitation.role === role,
  )

module.exports = {
  getInvitationData,
  setupInvitation,
  setupReviewerInvitation,
  getInvitation,
}
