import { th } from '@pubsweet/ui'
import styled, { css } from 'styled-components'

const defaultText = css`
  color: ${th('colorText')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`
const Root = styled.div`
  display: flex;
  flex-direction: row;
  margin: auto;
`

const Title = styled.div`
  ${defaultText};
  font-size: ${th('fontSizeBase')};
  color: ${th('colorPrimary')};
  margin-bottom: ${th('gridUnit')};
  text-align: left;
`

const Container = styled.div`
  flex: ${({ flex }) => flex || 1};
  padding: 0 ${th('subGridUnit')};
`

const SideBar = styled.div`
  flex: ${({ flex }) => flex || 1};
  background-color: ${th('colorBackground')};
  padding: 0 ${th('subGridUnit')};
`

const Header = styled.div`
  align-items: center;
  display: flex;
  flex-direction: row;
`

const BreadCrumbs = styled.div`
  & span {
    color: ${th('colorPrimary')};
    cursor: pointer;
    font-size: ${th('fontSizeBase')};
    text-align: left;
    
    &:after {
      content: '>';
      padding: 0 calc(${th('subGridUnit')}*2);
    }

    &:last-child {
      font-size: ${th('fontSizeBase')};
      font-weight: bold;
      margin-right: ${th('subGridUnit')};
      &:after {
        display: none;
    }
  }
`
const ManuscriptId = styled.div`
  ${defaultText};
  color: ${th('colorPrimary')};
  font-size: ${th('fontSizeBase')};
  margin-right: 8px;
  text-align: left;
  text-transform: uppercase;
  white-space: nowrap;
`

const LeftDetails = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  flex: ${({ flex }) => flex || 1};
  max-width: 75%;
`

const RightDetails = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  align-items: center;
  flex: ${({ flex }) => flex || 1};
  max-width: 75%;
`

const StatusLabel = styled.div`
  border: ${th('borderDefault')};
  ${defaultText};
  font-weight: bold;
  padding: 0 0.5em;
  text-align: left;
  text-transform: capitalize;
  line-height: 1.5;
  color: ${th('colorPrimary')};
`

const DateField = styled.span`
  ${defaultText};
  margin: 0 ${th('subGridUnit')};
  text-align: left;
`

export {
  Root,
  BreadCrumbs,
  Header,
  Title,
  ManuscriptId,
  Container,
  SideBar,
  LeftDetails,
  RightDetails,
  StatusLabel,
  DateField,
}
