const omit = require('lodash/omit')
const config = require('config')
const get = require('lodash/get')

const statuses = config.get('statuses')

const publicStatusesPermissions = ['author', 'reviewer']

module.exports = {
  parseReviewerAuthors: (coll, matchingCollPerm) => {
    if (['reviewer'].includes(matchingCollPerm.permission)) {
      coll.authors = coll.authors.map(a => omit(a, ['email']))
    }
  },
  setPublicStatuses: (coll, matchingCollPerm) => {
    const status = get(coll, 'status') || 'draft'
    coll.visibleStatus = statuses[status].public
    if (!publicStatusesPermissions.includes(matchingCollPerm.permission)) {
      coll.visibleStatus = statuses[coll.status].private
    }
  },
  filterRefusedReviewers: (coll, user) => {
    const matchingInv = coll.invitations.find(inv => inv.userId === user.id)
    if (matchingInv === undefined) return null
    if (matchingInv.hasAnswer === true && !matchingInv.isAccepted) return null
    return coll
  },
}
